-- ----------------------------
-- 访问日志表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_access_log`;
CREATE TABLE mortals_xhx_access_log(
    `id` bigint(20) NOT NULL    COMMENT '主键ID',
    `traceID` varchar(64)     COMMENT 'TraceId',
    `pspanId` int(9)     COMMENT '父服务调用id',
    `spanId` int(9)     COMMENT '当前服务跨度Id',
    `appName` varchar(64)     COMMENT '应用名称',
    `hostName` varchar(64)     COMMENT '实例IP',
    `targetServer` varchar(64)     COMMENT '目标服务',
    `logLevel` varchar(64)     COMMENT '日志等级',
    `requestIp` varchar(64)     COMMENT '请求者IP',
    `method` varchar(64)     COMMENT '请求方式',
    `schema` varchar(64)     COMMENT '协议',
    `ua` varchar(64)     COMMENT '用户浏览器UA',
    `uri` varchar(64)     COMMENT '请求URI',
    `requestData` varchar(2048)     COMMENT '请求参数，json序列化',
    `responseData` mediumtext     COMMENT '响应结果,',
    `logTime` datetime NOT NULL    COMMENT '日志产生时间',
    `requestTime` datetime     COMMENT '请求时间',
    `responseTime` datetime     COMMENT '响应时间',
    `duration` bigint(20)     COMMENT '持续时间，单位毫秒',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='访问日志';



-- ----------------------------
-- 业务日志表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_biz_log`;
CREATE TABLE mortals_xhx_biz_log(
    `id` bigint(20)     COMMENT '主键ID',
    `traceID` varchar(64)     COMMENT '追踪Id',
    `appName` varchar(64)     COMMENT '应用名称',
    `hostName` varchar(64)     COMMENT '实例IP',
    `logLevel` varchar(64)     COMMENT '日志等级',
    `userCode` varchar(64)     COMMENT '用户唯一标识',
    `deviceCode` varchar(64)     COMMENT '设备唯一标识',
    `eventTopic` varchar(64)     COMMENT '记录埋点的事件主题，方便实时计算或同步进行数据筛选',
    `eventTopicName` varchar(64)     COMMENT '记录埋点中文名称',
    `msg` mediumtext     COMMENT '事件参数，json',
    `logTime` datetime NOT NULL    COMMENT '日志产生时间',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='业务日志';

-- ----------------------------
-- 异常日志表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_error_log`;
CREATE TABLE mortals_xhx_error_log(
    `id` bigint(20)     COMMENT '主键ID',
    `traceID` varchar(64)     COMMENT '追踪Id',
    `serverType` varchar(64)     COMMENT '服务类型，webOS,android,IOS，服务后端',
    `appName` varchar(64)     COMMENT '应用名称',
    `hostName` varchar(64)     COMMENT '实例IP',
    `logLevel` varchar(64)     COMMENT '日志等级',
    `threadNo` varchar(64)     COMMENT '线程号',
    `error` text     COMMENT '异常堆栈信息',
    `response` text     COMMENT '响应结果',
    `logTime` datetime     COMMENT '日志产生时间',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='异常日志';

-- ----------------------------
-- 平台用户操作日志业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_operate_log`;
CREATE TABLE mortals_xhx_operate_log(
    `id` bigint(20)     COMMENT '主键ID',
    `platformMark` varchar(50)     COMMENT '平台标识',
    `userId` bigint(20)     COMMENT '用户id',
    `userName` varchar(50)     COMMENT '用户名称',
    `loginName` varchar(50)     COMMENT '用户登录名',
    `requestUrl` varchar(200)     COMMENT '请求地址',
    `content` varchar(2048)     COMMENT '操作内容，记录操作具体信息，如修改前修改或的数据',
    `ip` varchar(30)     COMMENT '操作IP地址',
    `logDate` datetime     COMMENT '操作时间',
    `operType` tinyint(2)     COMMENT '操作类型，0：新增，1：修改，2：删除',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='平台用户操作日志业务';

